@@ -31,6 +31,7 @@ module org.apache.lucene.backward_codecs {
   exports org.apache.lucene.backward_codecs.lucene86;
   exports org.apache.lucene.backward_codecs.lucene87;
   exports org.apache.lucene.backward_codecs.lucene90;
+  exports org.apache.lucene.backward_codecs.lucene90.blocktree;
   exports org.apache.lucene.backward_codecs.lucene91;
   exports org.apache.lucene.backward_codecs.lucene92;
   exports org.apache.lucene.backward_codecs.lucene94;
@@ -38,6 +39,9 @@ module org.apache.lucene.backward_codecs {
   exports org.apache.lucene.backward_codecs.lucene99;
   exports org.apache.lucene.backward_codecs.lucene912;
   exports org.apache.lucene.backward_codecs.lucene100;
+  exports org.apache.lucene.backward_codecs.lucene101;
+  exports org.apache.lucene.backward_codecs.lucene102;
+  exports org.apache.lucene.backward_codecs.lucene103;
   exports org.apache.lucene.backward_codecs.packed;
   exports org.apache.lucene.backward_codecs.store;
 
@@ -48,13 +52,19 @@ module org.apache.lucene.backward_codecs {
       org.apache.lucene.backward_codecs.lucene84.Lucene84PostingsFormat,
       org.apache.lucene.backward_codecs.lucene90.Lucene90PostingsFormat,
       org.apache.lucene.backward_codecs.lucene99.Lucene99PostingsFormat,
-      org.apache.lucene.backward_codecs.lucene912.Lucene912PostingsFormat;
+      org.apache.lucene.backward_codecs.lucene912.Lucene912PostingsFormat,
+      org.apache.lucene.backward_codecs.lucene101.Lucene101PostingsFormat,
+      org.apache.lucene.backward_codecs.lucene103.Lucene103PostingsFormat;
   provides org.apache.lucene.codecs.KnnVectorsFormat with
       org.apache.lucene.backward_codecs.lucene90.Lucene90HnswVectorsFormat,
       org.apache.lucene.backward_codecs.lucene91.Lucene91HnswVectorsFormat,
       org.apache.lucene.backward_codecs.lucene92.Lucene92HnswVectorsFormat,
       org.apache.lucene.backward_codecs.lucene94.Lucene94HnswVectorsFormat,
-      org.apache.lucene.backward_codecs.lucene95.Lucene95HnswVectorsFormat;
+      org.apache.lucene.backward_codecs.lucene95.Lucene95HnswVectorsFormat,
+      org.apache.lucene.backward_codecs.lucene99.Lucene99ScalarQuantizedVectorsFormat,
+      org.apache.lucene.backward_codecs.lucene99.Lucene99HnswScalarQuantizedVectorsFormat,
+      org.apache.lucene.backward_codecs.lucene102.Lucene102BinaryQuantizedVectorsFormat,
+      org.apache.lucene.backward_codecs.lucene102.Lucene102HnswBinaryQuantizedVectorsFormat;
   provides org.apache.lucene.codecs.Codec with
       org.apache.lucene.backward_codecs.lucene80.Lucene80Codec,
       org.apache.lucene.backward_codecs.lucene84.Lucene84Codec,
@@ -67,5 +77,7 @@ module org.apache.lucene.backward_codecs {
       org.apache.lucene.backward_codecs.lucene95.Lucene95Codec,
       org.apache.lucene.backward_codecs.lucene99.Lucene99Codec,
       org.apache.lucene.backward_codecs.lucene912.Lucene912Codec,
-      org.apache.lucene.backward_codecs.lucene100.Lucene100Codec;
+      org.apache.lucene.backward_codecs.lucene100.Lucene100Codec,
+      org.apache.lucene.backward_codecs.lucene101.Lucene101Codec,
+      org.apache.lucene.backward_codecs.lucene103.Lucene103Codec;
 }
