@@ -17,18 +17,19 @@
 package org.apache.lucene.backward_codecs.lucene912;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import org.apache.lucene.backward_codecs.lucene90.blocktree.FieldReader;
 import org.apache.lucene.backward_codecs.lucene90.blocktree.Stats;
-import org.apache.lucene.backward_codecs.lucene912.Lucene912PostingsReader.MutableImpactList;
 import org.apache.lucene.codecs.Codec;
 import org.apache.lucene.codecs.CompetitiveImpactAccumulator;
+import org.apache.lucene.codecs.Impact;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.index.DirectoryReader;
-import org.apache.lucene.index.Impact;
+import org.apache.lucene.index.FreqAndNormBuffer;
 import org.apache.lucene.index.IndexWriter;
 import org.apache.lucene.index.IndexWriterConfig;
 import org.apache.lucene.store.ByteArrayDataInput;
@@ -146,11 +147,15 @@ public class TestLucene912PostingsFormat extends BasePostingsFormatTestCase {
       try (IndexInput in = dir.openInput("foo", IOContext.DEFAULT)) {
         byte[] b = new byte[Math.toIntExact(in.length())];
         in.readBytes(b, 0, b.length);
-        List<Impact> impacts2 =
-            Lucene912PostingsReader.readImpacts(
-                new ByteArrayDataInput(b),
-                new MutableImpactList(impacts.size() + random().nextInt(3)));
-        assertEquals(impacts, impacts2);
+        FreqAndNormBuffer buffer = new FreqAndNormBuffer();
+        buffer.growNoCopy(impacts.size() + random().nextInt(3));
+        FreqAndNormBuffer impacts2 =
+            Lucene912PostingsReader.readImpacts(new ByteArrayDataInput(b), buffer);
+        List<Impact> impacts2AsList = new ArrayList<>();
+        for (int i = 0; i < impacts2.size; ++i) {
+          impacts2AsList.add(new Impact(impacts2.freqs[i], impacts2.norms[i]));
+        }
+        assertEquals(impacts, impacts2AsList);
       }
     }
   }
