@@ -20,7 +20,9 @@ import java.io.IOException;
 import java.util.Objects;
 import org.apache.lucene.index.FilterLeafReader.FilterTerms;
 import org.apache.lucene.index.FilterLeafReader.FilterTermsEnum;
+import org.apache.lucene.search.AcceptDocs;
 import org.apache.lucene.search.DocIdSetIterator;
+import org.apache.lucene.search.FilterDocIdSetIterator;
 import org.apache.lucene.search.KnnCollector;
 import org.apache.lucene.search.VectorScorer;
 import org.apache.lucene.util.Bits;
@@ -107,7 +109,10 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
 
     @Override
     public NumericDocValues getNumericDocValues(String field) throws IOException {
-      final NumericDocValues numericDocValues = super.getNumericDocValues(field);
+      return wrapNumericDocValues(super.getNumericDocValues(field));
+    }
+
+    private NumericDocValues wrapNumericDocValues(final NumericDocValues numericDocValues) {
       if (numericDocValues == null) {
         return null;
       }
@@ -189,7 +194,10 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
 
     @Override
     public SortedDocValues getSortedDocValues(String field) throws IOException {
-      final SortedDocValues sortedDocValues = super.getSortedDocValues(field);
+      return wrapSortedDocValues(super.getSortedDocValues(field));
+    }
+
+    private SortedDocValues wrapSortedDocValues(final SortedDocValues sortedDocValues) {
       if (sortedDocValues == null) {
         return null;
       }
@@ -232,6 +240,10 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
     @Override
     public SortedNumericDocValues getSortedNumericDocValues(String field) throws IOException {
       final SortedNumericDocValues sortedNumericDocValues = super.getSortedNumericDocValues(field);
+      final NumericDocValues numericDocValues = DocValues.unwrapSingleton(sortedNumericDocValues);
+      if (numericDocValues != null) {
+        return DocValues.singleton(wrapNumericDocValues(numericDocValues));
+      }
       if (sortedNumericDocValues == null) {
         return null;
       }
@@ -277,6 +289,10 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
       if (sortedSetDocValues == null) {
         return null;
       }
+      final SortedDocValues sortedDocValues = DocValues.unwrapSingleton(sortedSetDocValues);
+      if (sortedDocValues != null) {
+        return DocValues.singleton(wrapSortedDocValues(sortedDocValues));
+      }
       return new FilterSortedSetDocValues(sortedSetDocValues) {
 
         private int docToCheck = 0;
@@ -331,68 +347,92 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
       return new ExitableByteVectorValues(vectorValues);
     }
 
+    private class ExitableAcceptDocs extends AcceptDocs {
+
+      private final AcceptDocs in;
+      private Bits bits;
+
+      ExitableAcceptDocs(AcceptDocs in) {
+        this.in = in;
+      }
+
+      @Override
+      public Bits bits() throws IOException {
+        if (bits == null) {
+          // when acceptDocs is null due to no doc deleted, we will instantiate a new one that would
+          // match all docs to allow timeout checking.
+          final Bits updatedAcceptDocs =
+              in.bits() == null ? new Bits.MatchAllBits(maxDoc()) : in.bits();
+          bits =
+              new Bits() {
+                private static final int MAX_CALLS_BEFORE_QUERY_TIMEOUT_CHECK = 16;
+                private int calls;
+
+                @Override
+                public boolean get(int index) {
+                  if (calls++ % MAX_CALLS_BEFORE_QUERY_TIMEOUT_CHECK == 0) {
+                    checkAndThrowForSearchVectors();
+                  }
+
+                  return updatedAcceptDocs.get(index);
+                }
+
+                @Override
+                public int length() {
+                  return updatedAcceptDocs.length();
+                }
+              };
+        }
+        return bits;
+      }
+
+      @Override
+      public DocIdSetIterator iterator() throws IOException {
+        return new FilterDocIdSetIterator(in.iterator()) {
+          private int docToCheck = 0;
+
+          @Override
+          public int advance(int target) throws IOException {
+            final int advance = super.advance(target);
+            if (advance >= docToCheck) {
+              checkAndThrow(in);
+              docToCheck = advance + DOCS_BETWEEN_TIMEOUT_CHECK;
+            }
+            return advance;
+          }
+
+          @Override
+          public int nextDoc() throws IOException {
+            final int nextDoc = super.nextDoc();
+            if (nextDoc >= docToCheck) {
+              checkAndThrow(in);
+              docToCheck = nextDoc + DOCS_BETWEEN_TIMEOUT_CHECK;
+            }
+            return nextDoc;
+          }
+        };
+      }
+
+      @Override
+      public int cost() throws IOException {
+        return in.cost();
+      }
+    }
+
     @Override
     public void searchNearestVectors(
-        String field, float[] target, KnnCollector knnCollector, Bits acceptDocs)
+        String field, float[] target, KnnCollector knnCollector, AcceptDocs acceptDocs)
         throws IOException {
 
-      // when acceptDocs is null due to no doc deleted, we will instantiate a new one that would
-      // match all docs to allow timeout checking.
-      final Bits updatedAcceptDocs =
-          acceptDocs == null ? new Bits.MatchAllBits(maxDoc()) : acceptDocs;
-
-      Bits timeoutCheckingAcceptDocs =
-          new Bits() {
-            private static final int MAX_CALLS_BEFORE_QUERY_TIMEOUT_CHECK = 16;
-            private int calls;
-
-            @Override
-            public boolean get(int index) {
-              if (calls++ % MAX_CALLS_BEFORE_QUERY_TIMEOUT_CHECK == 0) {
-                checkAndThrowForSearchVectors();
-              }
-
-              return updatedAcceptDocs.get(index);
-            }
-
-            @Override
-            public int length() {
-              return updatedAcceptDocs.length();
-            }
-          };
-
+      AcceptDocs timeoutCheckingAcceptDocs = new ExitableAcceptDocs(acceptDocs);
       in.searchNearestVectors(field, target, knnCollector, timeoutCheckingAcceptDocs);
     }
 
     @Override
     public void searchNearestVectors(
-        String field, byte[] target, KnnCollector knnCollector, Bits acceptDocs)
+        String field, byte[] target, KnnCollector knnCollector, AcceptDocs acceptDocs)
         throws IOException {
-      // when acceptDocs is null due to no doc deleted, we will instantiate a new one that would
-      // match all docs to allow timeout checking.
-      final Bits updatedAcceptDocs =
-          acceptDocs == null ? new Bits.MatchAllBits(maxDoc()) : acceptDocs;
-
-      Bits timeoutCheckingAcceptDocs =
-          new Bits() {
-            private static final int MAX_CALLS_BEFORE_QUERY_TIMEOUT_CHECK = 16;
-            private int calls;
-
-            @Override
-            public boolean get(int index) {
-              if (calls++ % MAX_CALLS_BEFORE_QUERY_TIMEOUT_CHECK == 0) {
-                checkAndThrowForSearchVectors();
-              }
-
-              return updatedAcceptDocs.get(index);
-            }
-
-            @Override
-            public int length() {
-              return updatedAcceptDocs.length();
-            }
-          };
-
+      AcceptDocs timeoutCheckingAcceptDocs = new ExitableAcceptDocs(acceptDocs);
       in.searchNearestVectors(field, target, knnCollector, timeoutCheckingAcceptDocs);
     }
 
@@ -429,37 +469,10 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
     }
 
     private class ExitableFloatVectorValues extends FloatVectorValues {
-      private int docToCheck;
       private final FloatVectorValues vectorValues;
 
       public ExitableFloatVectorValues(FloatVectorValues vectorValues) {
         this.vectorValues = vectorValues;
-        docToCheck = 0;
-      }
-
-      @Override
-      public int advance(int target) throws IOException {
-        final int advance = vectorValues.advance(target);
-        if (advance >= docToCheck) {
-          checkAndThrow();
-          docToCheck = advance + DOCS_BETWEEN_TIMEOUT_CHECK;
-        }
-        return advance;
-      }
-
-      @Override
-      public int docID() {
-        return vectorValues.docID();
-      }
-
-      @Override
-      public int nextDoc() throws IOException {
-        final int nextDoc = vectorValues.nextDoc();
-        if (nextDoc >= docToCheck) {
-          checkAndThrow();
-          docToCheck = nextDoc + DOCS_BETWEEN_TIMEOUT_CHECK;
-        }
-        return nextDoc;
       }
 
       @Override
@@ -468,8 +481,13 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
       }
 
       @Override
-      public float[] vectorValue() throws IOException {
-        return vectorValues.vectorValue();
+      public float[] vectorValue(int ord) throws IOException {
+        return vectorValues.vectorValue(ord);
+      }
+
+      @Override
+      public int ordToDoc(int ord) {
+        return vectorValues.ordToDoc(ord);
       }
 
       @Override
@@ -477,61 +495,27 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
         return vectorValues.size();
       }
 
+      @Override
+      public DocIndexIterator iterator() {
+        return createExitableIterator(vectorValues.iterator(), queryTimeout);
+      }
+
       @Override
       public VectorScorer scorer(float[] target) throws IOException {
         return vectorValues.scorer(target);
       }
 
-      /**
-       * Throws {@link ExitingReaderException} if {@link QueryTimeout#shouldExit()} returns true, or
-       * if {@link Thread#interrupted()} returns true.
-       */
-      private void checkAndThrow() {
-        if (queryTimeout.shouldExit()) {
-          throw new ExitingReaderException(
-              "The request took too long to iterate over vector values. Timeout: "
-                  + queryTimeout.toString()
-                  + ", FloatVectorValues="
-                  + in);
-        } else if (Thread.interrupted()) {
-          throw new ExitingReaderException(
-              "Interrupted while iterating over vector values. FloatVectorValues=" + in);
-        }
+      @Override
+      public FloatVectorValues copy() {
+        throw new UnsupportedOperationException();
       }
     }
 
     private class ExitableByteVectorValues extends ByteVectorValues {
-      private int docToCheck;
       private final ByteVectorValues vectorValues;
 
       public ExitableByteVectorValues(ByteVectorValues vectorValues) {
         this.vectorValues = vectorValues;
-        docToCheck = 0;
-      }
-
-      @Override
-      public int advance(int target) throws IOException {
-        final int advance = vectorValues.advance(target);
-        if (advance >= docToCheck) {
-          checkAndThrow();
-          docToCheck = advance + DOCS_BETWEEN_TIMEOUT_CHECK;
-        }
-        return advance;
-      }
-
-      @Override
-      public int docID() {
-        return vectorValues.docID();
-      }
-
-      @Override
-      public int nextDoc() throws IOException {
-        final int nextDoc = vectorValues.nextDoc();
-        if (nextDoc >= docToCheck) {
-          checkAndThrow();
-          docToCheck = nextDoc + DOCS_BETWEEN_TIMEOUT_CHECK;
-        }
-        return nextDoc;
       }
 
       @Override
@@ -545,8 +529,18 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
       }
 
       @Override
-      public byte[] vectorValue() throws IOException {
-        return vectorValues.vectorValue();
+      public byte[] vectorValue(int ord) throws IOException {
+        return vectorValues.vectorValue(ord);
+      }
+
+      @Override
+      public int ordToDoc(int ord) {
+        return vectorValues.ordToDoc(ord);
+      }
+
+      @Override
+      public DocIndexIterator iterator() {
+        return createExitableIterator(vectorValues.iterator(), queryTimeout);
       }
 
       @Override
@@ -554,23 +548,66 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
         return vectorValues.scorer(target);
       }
 
-      /**
-       * Throws {@link ExitingReaderException} if {@link QueryTimeout#shouldExit()} returns true, or
-       * if {@link Thread#interrupted()} returns true.
-       */
+      @Override
+      public ByteVectorValues copy() {
+        throw new UnsupportedOperationException();
+      }
+    }
+  }
+
+  private static KnnVectorValues.DocIndexIterator createExitableIterator(
+      KnnVectorValues.DocIndexIterator delegate, QueryTimeout queryTimeout) {
+    return new KnnVectorValues.DocIndexIterator() {
+      private int nextCheck;
+
+      @Override
+      public int index() {
+        return delegate.index();
+      }
+
+      @Override
+      public int docID() {
+        return delegate.docID();
+      }
+
+      @Override
+      public int nextDoc() throws IOException {
+        int doc = delegate.nextDoc();
+        if (doc >= nextCheck) {
+          checkAndThrow();
+          nextCheck = doc + ExitableFilterAtomicReader.DOCS_BETWEEN_TIMEOUT_CHECK;
+        }
+        return doc;
+      }
+
+      @Override
+      public long cost() {
+        return delegate.cost();
+      }
+
+      @Override
+      public int advance(int target) throws IOException {
+        int doc = delegate.advance(target);
+        if (doc >= nextCheck) {
+          checkAndThrow();
+          nextCheck = doc + ExitableFilterAtomicReader.DOCS_BETWEEN_TIMEOUT_CHECK;
+        }
+        return doc;
+      }
+
       private void checkAndThrow() {
         if (queryTimeout.shouldExit()) {
           throw new ExitingReaderException(
-              "The request took too long to iterate over vector values. Timeout: "
+              "The request took too long to iterate over knn vector values. Timeout: "
                   + queryTimeout.toString()
-                  + ", ByteVectorValues="
-                  + in);
+                  + ", KnnVectorValues="
+                  + delegate);
         } else if (Thread.interrupted()) {
           throw new ExitingReaderException(
-              "Interrupted while iterating over vector values. ByteVectorValues=" + in);
+              "Interrupted while iterating over knn vector values. KnnVectorValues=" + delegate);
         }
       }
-    }
+    };
   }
 
   /** Wrapper class for another PointValues implementation that is used by ExitableFields. */
@@ -683,7 +720,7 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
       if (queryTimeout.shouldExit()) {
         throw new ExitingReaderException(
             "The request took too long to intersect point values. Timeout: "
-                + queryTimeout.toString()
+                + queryTimeout
                 + ", PointValues="
                 + pointValues);
       } else if (Thread.interrupted()) {
@@ -815,7 +852,7 @@ public class ExitableDirectoryReader extends FilterDirectoryReader {
   /** Wrapper class for another Terms implementation that is used by ExitableFields. */
   public static class ExitableTerms extends FilterTerms {
 
-    private QueryTimeout queryTimeout;
+    private final QueryTimeout queryTimeout;
 
     /** Constructor * */
     public ExitableTerms(Terms terms, QueryTimeout queryTimeout) {
