@@ -17,6 +17,7 @@
 package org.apache.lucene.index;
 
 import java.io.IOException;
+import org.apache.lucene.search.AcceptDocs;
 import org.apache.lucene.search.KnnCollector;
 import org.apache.lucene.search.ScoreDoc;
 import org.apache.lucene.search.TopDocs;
@@ -24,6 +25,7 @@ import org.apache.lucene.search.TopDocsCollector;
 import org.apache.lucene.search.TopKnnCollector;
 import org.apache.lucene.search.TotalHits;
 import org.apache.lucene.util.Bits;
+import org.apache.lucene.util.LiveDocs;
 
 /**
  * {@code LeafReader} is an abstract class, providing an interface for accessing an index. Search of
@@ -244,14 +246,14 @@ public abstract non-sealed class LeafReader extends IndexReader {
    * @param field the vector field to search
    * @param target the vector-valued query
    * @param k the number of docs to return
-   * @param acceptDocs {@link Bits} that represents the allowed documents to match, or {@code null}
-   *     if they are all allowed to match.
+   * @param acceptDocs {@link AcceptDocs} that represents the allowed documents to match
    * @param visitedLimit the maximum number of nodes that the search is allowed to visit
    * @return the k nearest neighbor documents, along with their (searchStrategy-specific) scores.
    * @lucene.experimental
    */
   public final TopDocs searchNearestVectors(
-      String field, float[] target, int k, Bits acceptDocs, int visitedLimit) throws IOException {
+      String field, float[] target, int k, AcceptDocs acceptDocs, int visitedLimit)
+      throws IOException {
     FieldInfo fi = getFieldInfos().fieldInfo(field);
     if (fi == null || fi.getVectorDimension() == 0) {
       return TopDocsCollector.EMPTY_TOPDOCS;
@@ -288,14 +290,14 @@ public abstract non-sealed class LeafReader extends IndexReader {
    * @param field the vector field to search
    * @param target the vector-valued query
    * @param k the number of docs to return
-   * @param acceptDocs {@link Bits} that represents the allowed documents to match, or {@code null}
-   *     if they are all allowed to match.
+   * @param acceptDocs {@link AcceptDocs} that represents the allowed documents to match
    * @param visitedLimit the maximum number of nodes that the search is allowed to visit
    * @return the k nearest neighbor documents, along with their (searchStrategy-specific) scores.
    * @lucene.experimental
    */
   public final TopDocs searchNearestVectors(
-      String field, byte[] target, int k, Bits acceptDocs, int visitedLimit) throws IOException {
+      String field, byte[] target, int k, AcceptDocs acceptDocs, int visitedLimit)
+      throws IOException {
     FieldInfo fi = getFieldInfos().fieldInfo(field);
     if (fi == null || fi.getVectorDimension() == 0) {
       return TopDocsCollector.EMPTY_TOPDOCS;
@@ -335,12 +337,12 @@ public abstract non-sealed class LeafReader extends IndexReader {
    * @param field the vector field to search
    * @param target the vector-valued query
    * @param knnCollector collector with settings for gathering the vector results.
-   * @param acceptDocs {@link Bits} that represents the allowed documents to match, or {@code null}
-   *     if they are all allowed to match.
+   * @param acceptDocs {@link AcceptDocs} that represents the allowed documents to match
    * @lucene.experimental
    */
   public abstract void searchNearestVectors(
-      String field, float[] target, KnnCollector knnCollector, Bits acceptDocs) throws IOException;
+      String field, float[] target, KnnCollector knnCollector, AcceptDocs acceptDocs)
+      throws IOException;
 
   /**
    * Return the k nearest neighbor documents as determined by comparison of their vector values for
@@ -364,12 +366,12 @@ public abstract non-sealed class LeafReader extends IndexReader {
    * @param field the vector field to search
    * @param target the vector-valued query
    * @param knnCollector collector with settings for gathering the vector results.
-   * @param acceptDocs {@link Bits} that represents the allowed documents to match, or {@code null}
-   *     if they are all allowed to match.
+   * @param acceptDocs {@link AcceptDocs} that represents the allowed documents to match
    * @lucene.experimental
    */
   public abstract void searchNearestVectors(
-      String field, byte[] target, KnnCollector knnCollector, Bits acceptDocs) throws IOException;
+      String field, byte[] target, KnnCollector knnCollector, AcceptDocs acceptDocs)
+      throws IOException;
 
   /**
    * Get the {@link FieldInfos} describing all fields in this reader.
@@ -391,6 +393,24 @@ public abstract non-sealed class LeafReader extends IndexReader {
    */
   public abstract Bits getLiveDocs();
 
+  /**
+   * Returns a {@link LiveDocs} view with efficient iteration support, or null if not available.
+   * When non-null, provides O(deletedDocs) iteration via {@link LiveDocs#deletedDocsIterator()}
+   * instead of O(maxDoc) scanning. Callers should fall back to {@link #getLiveDocs()} when null.
+   *
+   * <p>This method enables consumers to opt into efficient deleted document iteration when the
+   * underlying implementation supports it (e.g., SparseLiveDocs or DenseLiveDocs).
+   *
+   * <p>Default implementation returns the {@link LiveDocs} instance if {@link #getLiveDocs()}
+   * implements that interface.
+   *
+   * @lucene.experimental
+   */
+  public LiveDocs getLiveDocsWithDeletedIterator() {
+    Bits bits = getLiveDocs();
+    return bits instanceof LiveDocs ? (LiveDocs) bits : null;
+  }
+
   /**
    * Returns the {@link PointValues} used for numeric or spatial searches for the given field, or
    * null if there are no point fields.
