@@ -17,6 +17,7 @@
 package org.apache.lucene.search;
 
 import java.io.IOException;
+import org.apache.lucene.util.MathUtil;
 
 final class RangeDocIdStream extends DocIdStream {
 
@@ -58,4 +59,19 @@ final class RangeDocIdStream extends DocIdStream {
       return 0;
     }
   }
+
+  @Override
+  public int intoArray(int upTo, int[] array) {
+    int start = this.upTo;
+    upTo = Math.min(upTo, max);
+    upTo = MathUtil.unsignedMin(upTo, start + array.length);
+    if (upTo > start) {
+      for (int doc = start; doc < upTo; ++doc) {
+        array[doc - start] = doc;
+      }
+      this.upTo = upTo;
+      return upTo - start;
+    }
+    return 0;
+  }
 }
