@@ -24,12 +24,21 @@ import java.nio.file.NoSuchFileException;
 import java.nio.file.Path;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Comparator;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Random;
 import java.util.Set;
 import java.util.TreeSet;
+import java.util.concurrent.Callable;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.FieldType;
@@ -49,6 +58,7 @@ import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.Bits;
 import org.apache.lucene.util.BytesRef;
 import org.apache.lucene.util.IOUtils;
+import org.apache.lucene.util.NamedThreadFactory;
 import org.apache.lucene.util.SuppressForbidden;
 import org.apache.lucene.util.Version;
 import org.junit.Assume;
@@ -755,6 +765,67 @@ public class TestDirectoryReader extends LuceneTestCase {
     d.close();
   }
 
+  public void testGetIndexCommitWithExecutorService() throws IOException {
+
+    Directory d = newDirectory();
+    ExecutorService executorService =
+        Executors.newFixedThreadPool(4, new NamedThreadFactory("TestDirectoryReader"));
+
+    try {
+      // set up writer
+      IndexWriter writer =
+          new IndexWriter(
+              d,
+              newIndexWriterConfig(new MockAnalyzer(random()))
+                  .setMaxBufferedDocs(2)
+                  .setMergePolicy(newLogMergePolicy(10)));
+      for (int i = 0; i < 27; i++) addDocumentWithFields(writer);
+      writer.close();
+
+      SegmentInfos sis = SegmentInfos.readLatestCommit(d);
+      DirectoryReader r = DirectoryReader.open(d);
+      IndexCommit c = r.getIndexCommit();
+
+      assertEquals(sis.getSegmentsFileName(), c.getSegmentsFileName());
+
+      assertEquals(c, r.getIndexCommit());
+
+      // Change the index
+      writer =
+          new IndexWriter(
+              d,
+              newIndexWriterConfig(new MockAnalyzer(random()))
+                  .setOpenMode(OpenMode.APPEND)
+                  .setMaxBufferedDocs(2)
+                  .setMergePolicy(newLogMergePolicy(10)));
+      for (int i = 0; i < 7; i++) addDocumentWithFields(writer);
+      writer.close();
+
+      DirectoryReader r2 = DirectoryReader.openIfChanged(r, executorService);
+      assertNotNull(r2);
+      assertNotEquals(c, r2.getIndexCommit());
+      assertNotEquals(1, r2.getIndexCommit().getSegmentCount());
+      r2.close();
+
+      writer =
+          new IndexWriter(
+              d, newIndexWriterConfig(new MockAnalyzer(random())).setOpenMode(OpenMode.APPEND));
+      writer.forceMerge(1);
+      writer.close();
+
+      r2 = DirectoryReader.openIfChanged(r, executorService);
+      assertNotNull(r2);
+      assertNull(DirectoryReader.openIfChanged(r2, executorService));
+      assertEquals(1, r2.getIndexCommit().getSegmentCount());
+
+      r.close();
+      r2.close();
+    } finally {
+      executorService.shutdown();
+      d.close();
+    }
+  }
+
   static Document createDocument(String id) {
     Document doc = new Document();
     FieldType customType = new FieldType(TextField.TYPE_STORED);
@@ -775,6 +846,19 @@ public class TestDirectoryReader extends LuceneTestCase {
     dir.close();
   }
 
+  public void testNoDirWithExecutor() throws Throwable {
+    Path tempDir = createTempDir("doesnotexist");
+    Directory dir = newFSDirectory(tempDir);
+    ExecutorService executorService =
+        Executors.newFixedThreadPool(4, new NamedThreadFactory("TestDirectoryReader"));
+    try {
+      expectThrows(IndexNotFoundException.class, () -> DirectoryReader.open(dir, executorService));
+    } finally {
+      dir.close();
+      executorService.shutdown();
+    }
+  }
+
   // LUCENE-1509
   public void testNoDupCommitFileNames() throws Throwable {
 
@@ -1121,4 +1205,235 @@ public class TestDirectoryReader extends LuceneTestCase {
       DirectoryReader.open(commit, random().nextInt(Version.LATEST.major + 1), null).close();
     }
   }
+
+  public void testOpenWithExecutorService() throws IOException {
+    Directory dir = newDirectory();
+    createMultiSegmentIndex(dir, 5);
+
+    ExecutorService executor =
+        Executors.newFixedThreadPool(1, new NamedThreadFactory("TestDirectoryReader"));
+    try {
+      DirectoryReader reader = DirectoryReader.open(dir, executor);
+      assertNotNull(reader);
+      assertTrue(reader.numDocs() > 0);
+      reader.close();
+    } finally {
+      executor.shutdown();
+      dir.close();
+    }
+  }
+
+  public void testOpenWithLeafSorterAndExecutor() throws IOException {
+    Directory dir = newDirectory();
+    createMultiSegmentIndex(dir, 3);
+
+    ExecutorService executor =
+        Executors.newFixedThreadPool(1, new NamedThreadFactory("TestDirectoryReader"));
+    Comparator<LeafReader> sorter = (r1, r2) -> Integer.compare(r1.numDocs(), r2.numDocs());
+
+    try {
+      DirectoryReader reader = DirectoryReader.open(dir, sorter, executor);
+      assertNotNull(reader);
+      reader.close();
+    } finally {
+      executor.shutdown();
+      dir.close();
+    }
+  }
+
+  public void testOpenCommitWithExecutor() throws IOException {
+    Directory dir = newDirectory();
+    IndexWriter writer = new IndexWriter(dir, newIndexWriterConfig());
+    Document doc = new Document();
+    doc.add(newStringField("id", "1", Field.Store.YES));
+    writer.addDocument(doc);
+    writer.commit();
+    writer.close();
+
+    IndexCommit commit = DirectoryReader.listCommits(dir).get(0);
+    ExecutorService executor =
+        Executors.newFixedThreadPool(1, new NamedThreadFactory("TestDirectoryReader"));
+    try {
+      DirectoryReader reader = DirectoryReader.open(commit, executor);
+      assertNotNull(reader);
+      assertEquals(1, reader.numDocs());
+      reader.close();
+    } finally {
+      executor.shutdown();
+      dir.close();
+    }
+  }
+
+  public void testOpenCommitWithMinVersionAndExecutor() throws IOException {
+    Directory dir = newDirectory();
+    createMultiSegmentIndex(dir, 3);
+
+    ExecutorService executor =
+        Executors.newFixedThreadPool(1, new NamedThreadFactory("TestDirectoryReader"));
+    Comparator<LeafReader> sorter = (r1, r2) -> Integer.compare(r1.numDocs(), r2.numDocs());
+
+    try (DirectoryReader baseReader = DirectoryReader.open(dir)) {
+      IndexCommit commit = baseReader.getIndexCommit();
+      DirectoryReader reader =
+          DirectoryReader.open(commit, Version.MIN_SUPPORTED_MAJOR, sorter, executor);
+      assertNotNull(reader);
+      assertEquals(baseReader.numDocs(), reader.numDocs());
+      reader.close();
+    } finally {
+      executor.shutdown();
+      dir.close();
+    }
+  }
+
+  public void testNullExecutorService() throws IOException {
+    Directory dir = newDirectory();
+    createMultiSegmentIndex(dir, 3);
+
+    // Should work fine with null executor (fallback to sequential)
+    DirectoryReader reader = DirectoryReader.open(dir, (ExecutorService) null);
+    assertNotNull(reader);
+    assertTrue(reader.numDocs() > 0);
+    reader.close();
+    dir.close();
+  }
+
+  public void testExecutorServiceExceptionHandling() throws IOException {
+    Directory dir = newDirectory();
+    createMultiSegmentIndex(dir, 3);
+
+    // Test with shutdown executor
+    ExecutorService executor =
+        Executors.newFixedThreadPool(1, new NamedThreadFactory("TestDirectoryReader"));
+    executor.shutdown();
+
+    expectThrows(
+        RuntimeException.class,
+        () -> {
+          DirectoryReader.open(dir, executor);
+        });
+
+    dir.close();
+  }
+
+  public void testExecutorServicePartialFailure() throws IOException {
+    Directory dir = newDirectory();
+    createMultiSegmentIndex(dir, 3);
+
+    // Create an executor that fails on the second task but succeeds on others
+    ExecutorService executor = createExecutorServiceThatFailsOneTask();
+
+    try {
+      expectThrows(
+          RuntimeException.class,
+          () -> {
+            DirectoryReader.open(dir, executor);
+          });
+    } finally {
+      executor.shutdown();
+      dir.close();
+    }
+  }
+
+  private ExecutorService createExecutorServiceThatFailsOneTask() {
+    return new ExecutorService() {
+      private int taskCount = 0;
+      private final ExecutorService delegate =
+          Executors.newFixedThreadPool(2, new NamedThreadFactory("TestDirectoryReader"));
+
+      @Override
+      public <T> Future<T> submit(Callable<T> task) {
+        taskCount++;
+        if (taskCount == 2) {
+          // Second task fails
+          CompletableFuture<T> future = new CompletableFuture<>();
+          future.completeExceptionally(
+              new RuntimeException(new IOException("Simulated failure on segment")));
+          return future;
+        } else {
+          // Other tasks succeed normally
+          return delegate.submit(task);
+        }
+      }
+
+      @Override
+      public void shutdown() {
+        delegate.shutdown();
+      }
+
+      @Override
+      public List<Runnable> shutdownNow() {
+        return delegate.shutdownNow();
+      }
+
+      @Override
+      public boolean isShutdown() {
+        return delegate.isShutdown();
+      }
+
+      @Override
+      public boolean isTerminated() {
+        return delegate.isTerminated();
+      }
+
+      @Override
+      public boolean awaitTermination(long timeout, TimeUnit unit) throws InterruptedException {
+        return delegate.awaitTermination(timeout, unit);
+      }
+
+      @Override
+      public Future<?> submit(Runnable task) {
+        return delegate.submit(task);
+      }
+
+      @Override
+      public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks)
+          throws InterruptedException {
+        return delegate.invokeAll(tasks);
+      }
+
+      @Override
+      public <T> List<Future<T>> invokeAll(
+          Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit)
+          throws InterruptedException {
+        return delegate.invokeAll(tasks, timeout, unit);
+      }
+
+      @Override
+      public <T> T invokeAny(Collection<? extends Callable<T>> tasks)
+          throws InterruptedException, ExecutionException {
+        return delegate.invokeAny(tasks);
+      }
+
+      @Override
+      public <T> T invokeAny(Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit)
+          throws InterruptedException, ExecutionException, TimeoutException {
+        return delegate.invokeAny(tasks, timeout, unit);
+      }
+
+      @Override
+      public <T> Future<T> submit(Runnable task, T result) {
+        return delegate.submit(task, result);
+      }
+
+      @Override
+      public void execute(Runnable command) {
+        delegate.execute(command);
+      }
+    };
+  }
+
+  private void createMultiSegmentIndex(Directory dir, int numSegments) throws IOException {
+    IndexWriter writer =
+        new IndexWriter(
+            dir,
+            newIndexWriterConfig().setMaxBufferedDocs(2).setMergePolicy(NoMergePolicy.INSTANCE));
+    for (int i = 0; i < numSegments; i++) {
+      Document doc = new Document();
+      doc.add(newStringField("id", String.valueOf(i), Field.Store.YES));
+      doc.add(newTextField("content", "segment " + i + " content", Field.Store.YES));
+      writer.addDocument(doc);
+      writer.commit(); // Force new segment
+    }
+    writer.close();
+  }
 }
