@@ -16,6 +16,8 @@
  */
 package org.apache.lucene.search;
 
+import static org.apache.lucene.codecs.lucene99.Lucene99HnswVectorsFormat.DEFAULT_BEAM_WIDTH;
+import static org.apache.lucene.codecs.lucene99.Lucene99HnswVectorsFormat.DEFAULT_MAX_CONN;
 import static org.apache.lucene.search.DocIdSetIterator.NO_MORE_DOCS;
 
 import java.io.IOException;
@@ -28,6 +30,7 @@ import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
 import java.util.stream.IntStream;
+import org.apache.lucene.codecs.lucene99.Lucene99HnswVectorsFormat;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.IntField;
@@ -41,6 +44,7 @@ import org.apache.lucene.index.VectorSimilarityFunction;
 import org.apache.lucene.store.Directory;
 import org.apache.lucene.tests.index.RandomIndexWriter;
 import org.apache.lucene.tests.util.LuceneTestCase;
+import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.hnsw.HnswUtil;
 
 @LuceneTestCase.SuppressCodecs("SimpleText")
@@ -324,7 +328,7 @@ abstract class BaseVectorSimilarityQueryTestCase<
     try (Directory dir = getIndexStore(getRandomVectors(numDocs, dim));
         IndexWriter w = new IndexWriter(dir, newIndexWriterConfig())) {
       // Delete all documents
-      w.deleteDocuments(new MatchAllDocsQuery());
+      w.deleteDocuments(MatchAllDocsQuery.INSTANCE);
       w.commit();
 
       try (IndexReader reader = DirectoryReader.open(dir)) {
@@ -460,7 +464,14 @@ abstract class BaseVectorSimilarityQueryTestCase<
     Query filter = IntField.newSetQuery(idField, getFiltered(numFiltered));
 
     try (Directory indexStore = getIndexStore(vectors);
-        IndexWriter w = new IndexWriter(indexStore, newIndexWriterConfig())) {
+        IndexWriter w =
+            new IndexWriter(
+                indexStore,
+                newIndexWriterConfig()
+                    .setCodec(
+                        TestUtil.alwaysKnnVectorsFormat(
+                            new Lucene99HnswVectorsFormat(
+                                DEFAULT_MAX_CONN, DEFAULT_BEAM_WIDTH, 0))))) {
       // Force merge because smaller segments have few filtered docs and often fall back to exact
       // search, making this test flaky
       w.forceMerge(1);
@@ -576,7 +587,14 @@ abstract class BaseVectorSimilarityQueryTestCase<
   @SafeVarargs
   final Directory getIndexStore(V... vectors) throws IOException {
     Directory dir = newDirectory();
-    try (RandomIndexWriter writer = new RandomIndexWriter(random(), dir)) {
+    try (RandomIndexWriter writer =
+        new RandomIndexWriter(
+            random(),
+            dir,
+            newIndexWriterConfig()
+                .setCodec(
+                    TestUtil.alwaysKnnVectorsFormat(
+                        new Lucene99HnswVectorsFormat(DEFAULT_MAX_CONN, DEFAULT_BEAM_WIDTH, 0))))) {
       for (int i = 0; i < vectors.length; ++i) {
         Document doc = new Document();
         doc.add(getVectorField(vectorField, vectors[i], function));
