@@ -166,13 +166,13 @@ public class TestBooleanQuery extends LuceneTestCase {
     BooleanQuery bq1 =
         new BooleanQuery.Builder()
             .setMinimumNumberShouldMatch(random().nextInt(2))
-            .add(new MatchAllDocsQuery(), Occur.MUST)
+            .add(MatchAllDocsQuery.INSTANCE, Occur.MUST)
             .add(new TermQuery(new Term("foo", "bar")), Occur.FILTER)
             .build();
     BooleanQuery bq2 =
         new BooleanQuery.Builder()
             .setMinimumNumberShouldMatch(bq1.getMinimumNumberShouldMatch())
-            .add(new MatchAllDocsQuery(), Occur.MUST)
+            .add(MatchAllDocsQuery.INSTANCE, Occur.MUST)
             .add(new TermQuery(new Term("foo", "bar")), Occur.FILTER)
             .add(new TermQuery(new Term("foo", "bar")), Occur.FILTER)
             .build();
@@ -830,7 +830,7 @@ public class TestBooleanQuery extends LuceneTestCase {
 
     query =
         new BooleanQuery.Builder()
-            .add(new MatchAllDocsQuery(), Occur.MUST)
+            .add(MatchAllDocsQuery.INSTANCE, Occur.MUST)
             .add(LongPoint.newRangeQuery("long", 1L, 5L), Occur.FILTER)
             .build();
     // One query matches all docs, the count of the conjunction is the count of the other query
@@ -898,7 +898,7 @@ public class TestBooleanQuery extends LuceneTestCase {
 
     query =
         new BooleanQuery.Builder()
-            .add(new MatchAllDocsQuery(), Occur.SHOULD)
+            .add(MatchAllDocsQuery.INSTANCE, Occur.SHOULD)
             .add(LongPoint.newRangeQuery("long", 1L, 5L), Occur.SHOULD)
             .build();
     // One query matches all docs, the count of the disjunction is the number of docs
@@ -918,7 +918,7 @@ public class TestBooleanQuery extends LuceneTestCase {
         new BooleanQuery.Builder()
             .add(new TermQuery(new Term("string", "xyz")), Occur.MUST)
             .add(unknownCountQuery, Occur.MUST_NOT)
-            .add(new MatchAllDocsQuery(), Occur.MUST_NOT)
+            .add(MatchAllDocsQuery.INSTANCE, Occur.MUST_NOT)
             .build();
     weight = searcher.createWeight(query, ScoreMode.COMPLETE, 1f);
     // count of the first MUST_NOT clause is unknown, but the second MUST_NOT clause matches all
@@ -941,7 +941,7 @@ public class TestBooleanQuery extends LuceneTestCase {
     query =
         new BooleanQuery.Builder()
             .add(unknownCountQuery, Occur.SHOULD)
-            .add(new MatchAllDocsQuery(), Occur.SHOULD)
+            .add(MatchAllDocsQuery.INSTANCE, Occur.SHOULD)
             .build();
     weight = searcher.createWeight(query, ScoreMode.COMPLETE, 1f);
     // count of the first SHOULD clause is unknown, but the second SHOULD clause matches all docs
@@ -1308,7 +1308,7 @@ public class TestBooleanQuery extends LuceneTestCase {
             query = LongPoint.newExactQuery("long", 5L);
             break;
           case 4:
-            query = new MatchAllDocsQuery();
+            query = MatchAllDocsQuery.INSTANCE;
             break;
           default:
             query = LongPoint.newRangeQuery("long", 0L, 10L);
@@ -1409,10 +1409,10 @@ public class TestBooleanQuery extends LuceneTestCase {
     for (var occur : Occur.values()) {
       assertThrows(
           UnsupportedOperationException.class,
-          () -> bq.getClauses(occur).add(new MatchNoDocsQuery()));
+          () -> bq.getClauses(occur).add(MatchNoDocsQuery.INSTANCE));
     }
     assertThrows(
         UnsupportedOperationException.class,
-        () -> bq.clauses().add(new BooleanClause(new MatchNoDocsQuery(), Occur.SHOULD)));
+        () -> bq.clauses().add(new BooleanClause(MatchNoDocsQuery.INSTANCE, Occur.SHOULD)));
   }
 }
