@@ -16,6 +16,8 @@
  */
 package org.apache.lucene.search;
 
+import static org.hamcrest.Matchers.equalTo;
+
 import java.io.IOException;
 import org.apache.lucene.document.BinaryDocValuesField;
 import org.apache.lucene.document.Document;
@@ -79,8 +81,7 @@ public class TestSort extends LuceneTestCase {
     sortField2 = new SortField("foo", SortField.Type.LONG);
     assertDifferent(new Sort(sortField1), new Sort(sortField2));
 
-    sortField2 = new SortField("foo", SortField.Type.STRING);
-    sortField2.setMissingValue(SortField.STRING_FIRST);
+    sortField2 = new SortField("foo", SortField.Type.STRING, false, SortField.STRING_FIRST);
     assertDifferent(new Sort(sortField1), new Sort(sortField2));
 
     sortField2 = new SortField("foo", SortField.Type.STRING, false);
@@ -90,6 +91,18 @@ public class TestSort extends LuceneTestCase {
     assertDifferent(new Sort(sortField1), new Sort(sortField2));
   }
 
+  public void testStringMissingValues() {
+    Exception e =
+        expectThrows(
+            IllegalArgumentException.class,
+            () -> {
+              new Sort(new SortField("foo", SortField.Type.STRING, false, "invalid value"));
+            });
+    assertThat(
+        e.getMessage(),
+        equalTo("For Type.STRING, missing value must be either STRING_FIRST or STRING_LAST"));
+  }
+
   /** Tests sorting on type string */
   public void testString() throws IOException {
     Directory dir = newDirectory();
@@ -108,7 +121,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'foo'
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -136,7 +149,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING, true));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'foo' comes after 'bar' in reverse order
     assertEquals("foo", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -164,7 +177,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING_VAL));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'foo'
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -192,7 +205,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING_VAL, true));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'foo' comes after 'bar' in reverse order
     assertEquals("foo", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -224,7 +237,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.INT));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // numeric order
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -257,7 +270,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.INT, true));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // reverse numeric order
     assertEquals("300000", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -288,7 +301,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.INT));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null is treated as a 0
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -319,11 +332,10 @@ public class TestSort extends LuceneTestCase {
     writer.close();
 
     IndexSearcher searcher = newSearcher(ir);
-    SortField sortField = new SortField("value", SortField.Type.INT);
-    sortField.setMissingValue(Integer.MAX_VALUE);
+    SortField sortField = new SortField("value", SortField.Type.INT, false, Integer.MAX_VALUE);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null is treated as a Integer.MAX_VALUE
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -356,7 +368,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // numeric order
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -389,7 +401,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG, true));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // reverse numeric order
     assertEquals("3000000000", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -420,7 +432,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null is treated as 0
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -451,11 +463,10 @@ public class TestSort extends LuceneTestCase {
     writer.close();
 
     IndexSearcher searcher = newSearcher(ir);
-    SortField sortField = new SortField("value", SortField.Type.LONG);
-    sortField.setMissingValue(Long.MAX_VALUE);
+    SortField sortField = new SortField("value", SortField.Type.LONG, false, Long.MAX_VALUE);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null is treated as Long.MAX_VALUE
     assertEquals("-1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -488,7 +499,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // numeric order
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -521,7 +532,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT, true));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // reverse numeric order
     assertEquals("30.1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -552,7 +563,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null is treated as 0
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -583,11 +594,10 @@ public class TestSort extends LuceneTestCase {
     writer.close();
 
     IndexSearcher searcher = newSearcher(ir);
-    SortField sortField = new SortField("value", SortField.Type.FLOAT);
-    sortField.setMissingValue(Float.MAX_VALUE);
+    SortField sortField = new SortField("value", SortField.Type.FLOAT, false, Float.MAX_VALUE);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null is treated as Float.MAX_VALUE
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -624,7 +634,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(4, td.totalHits.value());
     // numeric order
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -657,7 +667,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // numeric order
     assertEquals("-0", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -693,7 +703,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE, true));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(4, td.totalHits.value());
     // numeric order
     assertEquals("30.1", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -731,7 +741,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(4, td.totalHits.value());
     // null treated as a 0
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -770,11 +780,10 @@ public class TestSort extends LuceneTestCase {
     writer.close();
 
     IndexSearcher searcher = newSearcher(ir);
-    SortField sortField = new SortField("value", SortField.Type.DOUBLE);
-    sortField.setMissingValue(Double.MAX_VALUE);
+    SortField sortField = new SortField("value", SortField.Type.DOUBLE, false, Double.MAX_VALUE);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(4, td.totalHits.value());
     // null treated as Double.MAX_VALUE
     assertEquals("-1.3", searcher.storedFields().document(td.scoreDocs[0].doc).get("value"));
@@ -825,7 +834,7 @@ public class TestSort extends LuceneTestCase {
             new SortField("value1", SortField.Type.STRING),
             new SortField("value2", SortField.Type.LONG));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(4, td.totalHits.value());
     // 'bar' comes before 'foo'
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value1"));
@@ -839,7 +848,7 @@ public class TestSort extends LuceneTestCase {
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[3].doc).get("value2"));
 
     // Now with overflow
-    td = searcher.search(new MatchAllDocsQuery(), 1, sort);
+    td = searcher.search(MatchAllDocsQuery.INSTANCE, 1, sort);
     assertEquals(4, td.totalHits.value());
     assertEquals("bar", searcher.storedFields().document(td.scoreDocs[0].doc).get("value1"));
     assertEquals("0", searcher.storedFields().document(td.scoreDocs[0].doc).get("value2"));
@@ -895,7 +904,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.STRING));
 
-    TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopFieldDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     assertNull(((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertNull(((FieldDoc) td.scoreDocs[1]).fields[0]);
@@ -931,7 +940,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.INT));
 
-    TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopFieldDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     assertEquals(0, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0, ((FieldDoc) td.scoreDocs[1]).fields[0]);
@@ -967,7 +976,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.LONG));
 
-    TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopFieldDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     assertEquals(0L, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0L, ((FieldDoc) td.scoreDocs[1]).fields[0]);
@@ -1003,7 +1012,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.DOUBLE));
 
-    TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopFieldDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     assertEquals(0.0, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0.0, ((FieldDoc) td.scoreDocs[1]).fields[0]);
@@ -1039,7 +1048,7 @@ public class TestSort extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir);
     Sort sort = new Sort(new SortField("value", SortField.Type.FLOAT));
 
-    TopFieldDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopFieldDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     assertEquals(0.0f, ((FieldDoc) td.scoreDocs[0]).fields[0]);
     assertEquals(0.0f, ((FieldDoc) td.scoreDocs[1]).fields[0]);
