@@ -35,6 +35,7 @@ import org.apache.lucene.document.KeywordField;
 import org.apache.lucene.document.LongField;
 import org.apache.lucene.document.LongPoint;
 import org.apache.lucene.document.NumericDocValuesField;
+import org.apache.lucene.document.SortedDocValuesField;
 import org.apache.lucene.document.StoredField;
 import org.apache.lucene.document.StringField;
 import org.apache.lucene.index.DirectoryReader;
@@ -48,6 +49,7 @@ import org.apache.lucene.index.IndexWriter;
 import org.apache.lucene.index.IndexWriterConfig;
 import org.apache.lucene.index.IndexableField;
 import org.apache.lucene.index.LeafReader;
+import org.apache.lucene.index.NoMergePolicy;
 import org.apache.lucene.index.PointValues;
 import org.apache.lucene.index.StoredFields;
 import org.apache.lucene.index.Term;
@@ -221,20 +223,17 @@ public class TestSortOptimization extends LuceneTestCase {
     final int numHits = 3;
 
     { // test that optimization is run when missing value setting of SortField is competitive with
-      // Puring.GREATER_THAN_OR_EQUAL_TO
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG);
-      sortField.setMissingValue(0L); // set a competitive missing value
+      // Pruning.GREATER_THAN_OR_EQUAL_TO
+      final SortField sortField = new SortField("my_field", SortField.Type.LONG, false, 0L);
       final Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
       assertEquals(topDocs.scoreDocs.length, numHits);
       assertNonCompetitiveHitsAreSkipped(topDocs.totalHits.value(), numDocs);
     }
     { // test that optimization is not run when missing value setting of SortField is competitive
-      // with Puring.SKIP
-      final SortField sortField1 = new SortField("my_field1", SortField.Type.LONG);
-      final SortField sortField2 = new SortField("my_field2", SortField.Type.LONG);
-      sortField1.setMissingValue(0L); // set a competitive missing value
-      sortField2.setMissingValue(0L); // set a competitive missing value
+      // with Pruning.SKIP
+      final SortField sortField1 = new SortField("my_field1", SortField.Type.LONG, false, 0L);
+      final SortField sortField2 = new SortField("my_field2", SortField.Type.LONG, false, 0L);
       final Sort sort = new Sort(sortField1, sortField2);
       TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
       assertEquals(topDocs.scoreDocs.length, numHits);
@@ -243,8 +242,7 @@ public class TestSortOptimization extends LuceneTestCase {
           numDocs); // assert that all documents were collected => optimization was not run
     }
     { // test that optimization is run when missing value setting of SortField is NOT competitive
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG);
-      sortField.setMissingValue(100L); // set a NON competitive missing value
+      final SortField sortField = new SortField("my_field", SortField.Type.LONG, false, 100L);
       final Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
       assertEquals(topDocs.scoreDocs.length, numHits);
@@ -256,8 +254,8 @@ public class TestSortOptimization extends LuceneTestCase {
       final long afterValue = Long.MAX_VALUE;
       final int afterDocID = 10 + random().nextInt(1000);
       FieldDoc after = new FieldDoc(afterDocID, Float.NaN, new Long[] {afterValue});
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG);
-      sortField.setMissingValue(Long.MAX_VALUE); // set a competitive missing value
+      final SortField sortField =
+          new SortField("my_field", SortField.Type.LONG, false, Long.MAX_VALUE);
       final Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSearchHits(reader, sort, numHits, after);
       assertEquals(topDocs.scoreDocs.length, numHits);
@@ -269,8 +267,8 @@ public class TestSortOptimization extends LuceneTestCase {
       final long afterValue = Long.MAX_VALUE;
       final int afterDocID = 10 + random().nextInt(1000);
       FieldDoc after = new FieldDoc(afterDocID, Float.NaN, new Long[] {afterValue});
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG, true);
-      sortField.setMissingValue(Long.MAX_VALUE); // set a competitive missing value
+      final SortField sortField =
+          new SortField("my_field", SortField.Type.LONG, true, Long.MAX_VALUE);
       final Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSearchHits(reader, sort, numHits, after);
       assertEquals(topDocs.scoreDocs.length, numHits);
@@ -282,8 +280,7 @@ public class TestSortOptimization extends LuceneTestCase {
       // with after on asc order
       long afterValue = 3L;
       FieldDoc after = new FieldDoc(3, Float.NaN, new Long[] {afterValue});
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG);
-      sortField.setMissingValue(2L);
+      final SortField sortField = new SortField("my_field", SortField.Type.LONG, false, 2L);
       final Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSearchHits(reader, sort, numHits, after);
       assertEquals(topDocs.scoreDocs.length, numHits);
@@ -336,16 +333,14 @@ public class TestSortOptimization extends LuceneTestCase {
     TopDocs topDocs2;
 
     { // Test that optimization is run with NumericDocValues when missing value is NOT competitive
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG, true);
-      sortField.setMissingValue(0L); // missing value is not competitive
+      final SortField sortField = new SortField("my_field", SortField.Type.LONG, true, 0L);
       final Sort sort = new Sort(sortField);
       topDocs1 = assertSearchHits(reader, sort, numHits, null);
       assertNonCompetitiveHitsAreSkipped(topDocs1.totalHits.value(), numDocs);
     }
     { // Test that sort on sorted numeric field without sort optimization and with sort optimization
       // produce the same results
-      final SortField sortField = new SortField("my_field", SortField.Type.LONG, true);
-      sortField.setMissingValue(0L); // missing value is not competitive
+      final SortField sortField = new SortField("my_field", SortField.Type.LONG, true, 0L);
       final Sort sort = new Sort(sortField);
       sortField.setOptimizeSortWithPoints(false);
       topDocs2 = assertSearchHits(reader, sort, numHits, null);
@@ -364,10 +359,9 @@ public class TestSortOptimization extends LuceneTestCase {
     }
 
     { // Test that we can't do optimization via NumericDocValues when there are multiple comparators
-      final SortField sortField1 = new SortField("my_field", SortField.Type.LONG, true);
-      final SortField sortField2 = new SortField("other", SortField.Type.LONG, true);
-      sortField1.setMissingValue(0L); // missing value is not competitive
-      sortField2.setMissingValue(0L); // missing value is not competitive
+      // missing values are not competitive
+      final SortField sortField1 = new SortField("my_field", SortField.Type.LONG, true, 0L);
+      final SortField sortField2 = new SortField("other", SortField.Type.LONG, true, 0L);
       final Sort multiSorts = new Sort(new SortField[] {sortField1, sortField2});
       TopDocs topDocs = assertSearchHits(reader, multiSorts, numHits, null);
       // can't optimization with NumericDocValues when there are multiple comparators
@@ -798,26 +792,26 @@ public class TestSortOptimization extends LuceneTestCase {
     SortField longSortOnIntField = new SortField("intField", SortField.Type.LONG);
     assertThrows(
         IllegalArgumentException.class,
-        () -> searcher.search(new MatchAllDocsQuery(), 1, new Sort(longSortOnIntField)));
+        () -> searcher.search(MatchAllDocsQuery.INSTANCE, 1, new Sort(longSortOnIntField)));
     // assert that when sort optimization is disabled we can use LONG sort on int field
     longSortOnIntField.setOptimizeSortWithIndexedData(false);
-    searcher.search(new MatchAllDocsQuery(), 1, new Sort(longSortOnIntField));
+    searcher.search(MatchAllDocsQuery.INSTANCE, 1, new Sort(longSortOnIntField));
 
     SortField intSortOnLongField = new SortField("longField", SortField.Type.INT);
     assertThrows(
         IllegalArgumentException.class,
-        () -> searcher.search(new MatchAllDocsQuery(), 1, new Sort(intSortOnLongField)));
+        () -> searcher.search(MatchAllDocsQuery.INSTANCE, 1, new Sort(intSortOnLongField)));
     // assert that when sort optimization is disabled we can use INT sort on long field
     intSortOnLongField.setOptimizeSortWithIndexedData(false);
-    searcher.search(new MatchAllDocsQuery(), 1, new Sort(intSortOnLongField));
+    searcher.search(MatchAllDocsQuery.INSTANCE, 1, new Sort(intSortOnLongField));
 
     SortField intSortOnIntRangeField = new SortField("intRange", SortField.Type.INT);
     assertThrows(
         IllegalArgumentException.class,
-        () -> searcher.search(new MatchAllDocsQuery(), 1, new Sort(intSortOnIntRangeField)));
+        () -> searcher.search(MatchAllDocsQuery.INSTANCE, 1, new Sort(intSortOnIntRangeField)));
     // assert that when sort optimization is disabled we can use INT sort on intRange field
     intSortOnIntRangeField.setOptimizeSortWithIndexedData(false);
-    searcher.search(new MatchAllDocsQuery(), 1, new Sort(intSortOnIntRangeField));
+    searcher.search(MatchAllDocsQuery.INSTANCE, 1, new Sort(intSortOnIntRangeField));
 
     reader.close();
     dir.close();
@@ -905,7 +899,7 @@ public class TestSortOptimization extends LuceneTestCase {
       int batch = 1 + random().nextInt(100);
       Query query =
           random().nextBoolean()
-              ? new MatchAllDocsQuery()
+              ? MatchAllDocsQuery.INSTANCE
               : LongPoint.newRangeQuery("seq_no", 0, Long.MAX_VALUE);
       TopDocs topDocs = assertSearchHits(reader, query, new Sort(sortField), batch, after);
       int expectedHits = Math.min(seqNos.size() - visitedHits, batch);
@@ -1008,14 +1002,25 @@ public class TestSortOptimization extends LuceneTestCase {
     }
   }
 
-  public void testStringSortOptimization() throws IOException {
+  public void testStringSortOptimizationBasedPostings() throws IOException {
+    testStringSortOptimization((field, value) -> new KeywordField(field, value, Field.Store.NO));
+  }
+
+  public void testStringSortOptimizationBasedDVSkipper() throws IOException {
+    testStringSortOptimization(SortedDocValuesField::indexedField);
+  }
+
+  private void testStringSortOptimization(
+      BiFunction<String, BytesRef, IndexableField> fieldsBuilder) throws IOException {
     final Directory dir = newDirectory();
     final IndexWriter writer = new IndexWriter(dir, new IndexWriterConfig());
     final int numDocs = atLeast(10000);
     for (int i = 0; i < numDocs; ++i) {
       final Document doc = new Document();
-      final BytesRef value = new BytesRef(Integer.toString(random().nextInt(1000)));
-      doc.add(new KeywordField("my_field", value, Field.Store.NO));
+      // Random values that roughly correlate with index order, to make skipper implementation
+      // useful
+      final BytesRef value = new BytesRef(Integer.toString(random().nextInt(i, i + 20)));
+      doc.add(fieldsBuilder.apply("my_field", value));
       writer.addDocument(doc);
       if (i == 7000) writer.flush(); // multiple segments
     }
@@ -1027,19 +1032,33 @@ public class TestSortOptimization extends LuceneTestCase {
     dir.close();
   }
 
-  public void testStringSortOptimizationWithMissingValues() throws IOException {
+  public void testStringSortOptimizationWithMissingValuesBasedPostings() throws IOException {
+    testStringSortOptimizationWithMissingValues(
+        (field, value) -> new KeywordField(field, value, Field.Store.NO));
+  }
+
+  public void testStringSortOptimizationWithMissingValuesBasedDVSkipper() throws IOException {
+    testStringSortOptimizationWithMissingValues(SortedDocValuesField::indexedField);
+  }
+
+  private void testStringSortOptimizationWithMissingValues(
+      BiFunction<String, BytesRef, IndexableField> fieldsBuilder) throws IOException {
     final Directory dir = newDirectory();
     final IndexWriter writer =
         new IndexWriter(dir, new IndexWriterConfig().setMergePolicy(newLogMergePolicy()));
-    final int numDocs = atLeast(10000);
+    // Larger number of documents as some of them are missing values and we still want
+    // to have multiple skipper blocks of 4096 entries.
+    final int numDocs = atLeast(30000);
     // one segment with all values missing to start with
     writer.addDocument(new Document());
     for (int i = 0; i < numDocs - 2; ++i) {
       if (i == 7000) writer.flush(); // multiple segments
       final Document doc = new Document();
       if (random().nextInt(2) == 0) {
-        final BytesRef value = new BytesRef(Integer.toString(random().nextInt(1000)));
-        doc.add(new KeywordField("my_field", value, Field.Store.NO));
+        // Random values that roughly correlate with index order, to make skipper implementation
+        // useful
+        final BytesRef value = new BytesRef(Integer.toString(random().nextInt(i, i + 20)));
+        doc.add(fieldsBuilder.apply("my_field", value));
       }
       writer.addDocument(doc);
     }
@@ -1053,22 +1072,118 @@ public class TestSortOptimization extends LuceneTestCase {
     dir.close();
   }
 
+  public void testStringSortOptimizationFieldMissingInSegmentBasedPostings() throws IOException {
+    testStringSortOptimizationFieldMissingInSegment(
+        (field, value) -> new KeywordField(field, value, Field.Store.NO));
+  }
+
+  public void testStringSortOptimizationFieldMissingInSegmentBasedDVSkipper() throws IOException {
+    testStringSortOptimizationFieldMissingInSegment(SortedDocValuesField::indexedField);
+  }
+
+  /**
+   * Test that when a segment doesn't contain the sort field at all (fieldInfo == null), the
+   * optimization still works. All docs in such a segment have missing values, and when missing
+   * values are non-competitive the entire segment should be skippable.
+   */
+  private void testStringSortOptimizationFieldMissingInSegment(
+      BiFunction<String, BytesRef, IndexableField> fieldsBuilder) throws IOException {
+    final Directory dir = newDirectory();
+    // Use NoMergePolicy to ensure we have deterministic segment geometry
+    final IndexWriter writer =
+        new IndexWriter(dir, new IndexWriterConfig().setMergePolicy(NoMergePolicy.INSTANCE));
+
+    // First segment: a small number of docs with the keyword field, enough to fill the top-N queue.
+    final int docsWithField = 20;
+    for (int i = 0; i < docsWithField; i++) {
+      final Document doc = new Document();
+      doc.add(fieldsBuilder.apply("my_field", new BytesRef(Integer.toString(i))));
+      writer.addDocument(doc);
+    }
+    writer.flush();
+
+    // Second segment: many docs WITHOUT the keyword field. The field doesn't exist in this
+    // segment's FieldInfos at all, so every doc has a missing value for the sort field.
+    final int docsWithoutField = atLeast(10000);
+    for (int i = 0; i < docsWithoutField; i++) {
+      writer.addDocument(new Document());
+    }
+
+    final DirectoryReader reader = DirectoryReader.open(writer);
+    writer.close();
+
+    final int numDocs = docsWithField + docsWithoutField;
+    final int numHits = 5;
+
+    { // ascending sort with missing-last: once the queue fills from the first segment,
+      // all docs in the second segment have non-competitive missing values and should be skipped
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
+      Sort sort = new Sort(sortField);
+      TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
+      assertNonCompetitiveHitsAreSkipped(topDocs.totalHits.value(), numDocs);
+    }
+
+    { // descending sort with missing-last
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", true, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
+      Sort sort = new Sort(sortField);
+      TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
+
+      sortField.setOptimizeSortWithIndexedData(false);
+      sort = new Sort(sortField);
+      TopDocs unpruned = assertSearchHits(reader, sort, numHits, null);
+
+      CheckHits.checkEqual(MatchAllDocsQuery.INSTANCE, topDocs.scoreDocs, unpruned.scoreDocs);
+    }
+
+    { // descending sort with missing-first: once the queue fills from the first segment,
+      // all docs in the second segment have non-competitive missing values and should be skipped
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", true, SortedSetSelector.Type.MIN, SortField.STRING_FIRST);
+      Sort sort = new Sort(sortField);
+      TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
+      assertNonCompetitiveHitsAreSkipped(topDocs.totalHits.value(), numDocs);
+    }
+
+    { // ascending sort with missing-first
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_FIRST);
+      Sort sort = new Sort(sortField);
+      TopDocs topDocs = assertSearchHits(reader, sort, numHits, null);
+
+      sortField.setOptimizeSortWithIndexedData(false);
+      sort = new Sort(sortField);
+      TopDocs unpruned = assertSearchHits(reader, sort, numHits, null);
+
+      CheckHits.checkEqual(MatchAllDocsQuery.INSTANCE, topDocs.scoreDocs, unpruned.scoreDocs);
+    }
+
+    reader.close();
+    dir.close();
+  }
+
   private void doTestStringSortOptimization(DirectoryReader reader) throws IOException {
     final int numDocs = reader.numDocs();
     final int numHits = 5;
 
     { // simple ascending sort
       SortField sortField =
-          KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_LAST);
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
       Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSort(reader, sort, numHits, null);
       assertNonCompetitiveHitsAreSkipped(topDocs.totalHits.value(), numDocs);
     }
 
     { // simple descending sort
-      SortField sortField = KeywordField.newSortField("my_field", true, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_FIRST);
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", true, SortedSetSelector.Type.MIN, SortField.STRING_FIRST);
       Sort sort = new Sort(sortField);
       TopDocs topDocs = assertSort(reader, sort, numHits, null);
       assertNonCompetitiveHitsAreSkipped(topDocs.totalHits.value(), numDocs);
@@ -1076,23 +1191,24 @@ public class TestSortOptimization extends LuceneTestCase {
 
     { // ascending sort that returns missing values first
       SortField sortField =
-          KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_FIRST);
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_FIRST);
       Sort sort = new Sort(sortField);
       assertSort(reader, sort, numHits, null);
     }
 
     { // descending sort that returns missing values last
-      SortField sortField = KeywordField.newSortField("my_field", true, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_LAST);
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", true, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
       Sort sort = new Sort(sortField);
       assertSort(reader, sort, numHits, null);
     }
 
     { // paging ascending sort with after
       SortField sortField =
-          KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_LAST);
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
       Sort sort = new Sort(sortField);
       BytesRef afterValue = new BytesRef(random().nextBoolean() ? "23" : "230000000");
       FieldDoc after = new FieldDoc(2, Float.NaN, new Object[] {afterValue});
@@ -1101,8 +1217,9 @@ public class TestSortOptimization extends LuceneTestCase {
     }
 
     { // paging descending sort with after
-      SortField sortField = KeywordField.newSortField("my_field", true, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_FIRST);
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", true, SortedSetSelector.Type.MIN, SortField.STRING_FIRST);
       Sort sort = new Sort(sortField);
       BytesRef afterValue = new BytesRef(random().nextBoolean() ? "17" : "170000000");
       FieldDoc after = new FieldDoc(2, Float.NaN, new Object[] {afterValue});
@@ -1112,8 +1229,8 @@ public class TestSortOptimization extends LuceneTestCase {
 
     { // paging ascending sort with after that returns missing values first
       SortField sortField =
-          KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_FIRST);
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_FIRST);
       Sort sort = new Sort(sortField);
       BytesRef afterValue = new BytesRef(random().nextBoolean() ? "23" : "230000000");
       FieldDoc after = new FieldDoc(2, Float.NaN, new Object[] {afterValue});
@@ -1122,8 +1239,9 @@ public class TestSortOptimization extends LuceneTestCase {
     }
 
     { // paging descending sort with after that returns missing values first
-      SortField sortField = KeywordField.newSortField("my_field", true, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_LAST);
+      SortField sortField =
+          KeywordField.newSortField(
+              "my_field", true, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
       Sort sort = new Sort(sortField);
       BytesRef afterValue = new BytesRef(random().nextBoolean() ? "17" : "170000000");
       FieldDoc after = new FieldDoc(2, Float.NaN, new Object[] {afterValue});
@@ -1133,8 +1251,8 @@ public class TestSortOptimization extends LuceneTestCase {
 
     { // test that if there is the secondary sort on _score, hits are still skipped
       SortField sortField =
-          KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_LAST);
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
       Sort sort = new Sort(sortField, FIELD_SCORE);
       TopDocs topDocs = assertSort(reader, sort, numHits, null);
       assertNonCompetitiveHitsAreSkipped(topDocs.totalHits.value(), numDocs);
@@ -1142,8 +1260,8 @@ public class TestSortOptimization extends LuceneTestCase {
 
     { // test that if string field is a secondary sort, no optimization is run
       SortField sortField =
-          KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-      sortField.setMissingValue(SortField.STRING_LAST);
+          KeywordField.newSortField(
+              "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
       Sort sort = new Sort(FIELD_SCORE, sortField);
       TopDocs topDocs = assertSort(reader, sort, numHits, null);
       assertEquals(
@@ -1153,8 +1271,9 @@ public class TestSortOptimization extends LuceneTestCase {
   }
 
   public void doTestStringSortOptimizationDisabled(DirectoryReader reader) throws IOException {
-    SortField sortField = KeywordField.newSortField("my_field", false, SortedSetSelector.Type.MIN);
-    sortField.setMissingValue(SortField.STRING_LAST);
+    SortField sortField =
+        KeywordField.newSortField(
+            "my_field", false, SortedSetSelector.Type.MIN, SortField.STRING_LAST);
     sortField.setOptimizeSortWithIndexedData(false);
 
     Sort sort = new Sort(sortField);
@@ -1184,7 +1303,7 @@ public class TestSortOptimization extends LuceneTestCase {
 
   private TopFieldDocs assertSearchHits(DirectoryReader reader, Sort sort, int n, FieldDoc after)
       throws IOException {
-    return assertSearchHits(reader, new MatchAllDocsQuery(), sort, n, after);
+    return assertSearchHits(reader, MatchAllDocsQuery.INSTANCE, sort, n, after);
   }
 
   private TopFieldDocs assertSearchHits(
