@@ -52,7 +52,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
 
     Sort sort = new Sort(new SortedSetSortField("value", false, SortedSetSelector.Type.MAX));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'baz' comes before 'foo'
     assertEquals("2", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -82,7 +82,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
 
     Sort sort = new Sort(new SortedSetSortField("value", true, SortedSetSelector.Type.MAX));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'baz' comes before 'foo'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -113,11 +113,11 @@ public class TestSortedSetSelector extends LuceneTestCase {
     // slow wrapper does not support random access ordinals (there is no need for that!)
     IndexSearcher searcher = newSearcher(ir, false);
 
-    SortField sortField = new SortedSetSortField("value", false, SortedSetSelector.Type.MAX);
-    sortField.setMissingValue(SortField.STRING_FIRST);
+    SortField sortField =
+        new SortedSetSortField("value", false, SortedSetSelector.Type.MAX, SortField.STRING_FIRST);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null comes first
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -150,11 +150,11 @@ public class TestSortedSetSelector extends LuceneTestCase {
     // slow wrapper does not support random access ordinals (there is no need for that!)
     IndexSearcher searcher = newSearcher(ir, false);
 
-    SortField sortField = new SortedSetSortField("value", false, SortedSetSelector.Type.MAX);
-    sortField.setMissingValue(SortField.STRING_LAST);
+    SortField sortField =
+        new SortedSetSortField("value", false, SortedSetSelector.Type.MAX, SortField.STRING_LAST);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // 'baz' comes before 'foo'
     assertEquals("3", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -184,7 +184,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", false, SortedSetSelector.Type.MAX));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'baz'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -215,7 +215,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MIN));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'b' comes before 'c'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -246,7 +246,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", true, SortedSetSelector.Type.MIDDLE_MIN));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'b' comes before 'c'
     assertEquals("2", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -278,11 +278,12 @@ public class TestSortedSetSelector extends LuceneTestCase {
 
     // slow wrapper does not support random access ordinals (there is no need for that!)
     IndexSearcher searcher = newSearcher(ir, false);
-    SortField sortField = new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MIN);
-    sortField.setMissingValue(SortField.STRING_FIRST);
+    SortField sortField =
+        new SortedSetSortField(
+            "value", false, SortedSetSelector.Type.MIDDLE_MIN, SortField.STRING_FIRST);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null comes first
     assertEquals("3", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -316,11 +317,12 @@ public class TestSortedSetSelector extends LuceneTestCase {
 
     // slow wrapper does not support random access ordinals (there is no need for that!)
     IndexSearcher searcher = newSearcher(ir, false);
-    SortField sortField = new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MIN);
-    sortField.setMissingValue(SortField.STRING_LAST);
+    SortField sortField =
+        new SortedSetSortField(
+            "value", false, SortedSetSelector.Type.MIDDLE_MIN, SortField.STRING_LAST);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // 'b' comes before 'c'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -350,7 +352,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MIN));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'baz'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -381,7 +383,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MAX));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'b' comes before 'c'
     assertEquals("2", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -412,7 +414,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", true, SortedSetSelector.Type.MIDDLE_MAX));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'b' comes before 'c'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -444,11 +446,12 @@ public class TestSortedSetSelector extends LuceneTestCase {
 
     // slow wrapper does not support random access ordinals (there is no need for that!)
     IndexSearcher searcher = newSearcher(ir, false);
-    SortField sortField = new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MAX);
-    sortField.setMissingValue(SortField.STRING_FIRST);
+    SortField sortField =
+        new SortedSetSortField(
+            "value", false, SortedSetSelector.Type.MIDDLE_MAX, SortField.STRING_FIRST);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // null comes first
     assertEquals("3", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -482,11 +485,12 @@ public class TestSortedSetSelector extends LuceneTestCase {
 
     // slow wrapper does not support random access ordinals (there is no need for that!)
     IndexSearcher searcher = newSearcher(ir, false);
-    SortField sortField = new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MAX);
-    sortField.setMissingValue(SortField.STRING_LAST);
+    SortField sortField =
+        new SortedSetSortField(
+            "value", false, SortedSetSelector.Type.MIDDLE_MAX, SortField.STRING_LAST);
     Sort sort = new Sort(sortField);
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(3, td.totalHits.value());
     // 'b' comes before 'c'
     assertEquals("2", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
@@ -516,7 +520,7 @@ public class TestSortedSetSelector extends LuceneTestCase {
     IndexSearcher searcher = newSearcher(ir, false);
     Sort sort = new Sort(new SortedSetSortField("value", false, SortedSetSelector.Type.MIDDLE_MAX));
 
-    TopDocs td = searcher.search(new MatchAllDocsQuery(), 10, sort);
+    TopDocs td = searcher.search(MatchAllDocsQuery.INSTANCE, 10, sort);
     assertEquals(2, td.totalHits.value());
     // 'bar' comes before 'baz'
     assertEquals("1", searcher.storedFields().document(td.scoreDocs[0].doc).get("id"));
