@@ -17,8 +17,10 @@
 package org.apache.lucene.search;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import org.apache.lucene.codecs.Impact;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.Field.Store;
@@ -26,7 +28,7 @@ import org.apache.lucene.document.FieldType;
 import org.apache.lucene.document.StringField;
 import org.apache.lucene.document.TextField;
 import org.apache.lucene.index.DirectoryReader;
-import org.apache.lucene.index.Impact;
+import org.apache.lucene.index.FreqAndNormBuffer;
 import org.apache.lucene.index.Impacts;
 import org.apache.lucene.index.ImpactsEnum;
 import org.apache.lucene.index.ImpactsSource;
@@ -350,10 +352,18 @@ public class TestSynonymQuery extends LuceneTestCase {
     assertEquals(impacts.length, actual.numLevels());
     for (int i = 0; i < impacts.length; ++i) {
       assertEquals(docIdUpTo[i], actual.getDocIdUpTo(i));
-      assertEquals(Arrays.asList(impacts[i]), actual.getImpacts(i));
+      assertEquals(Arrays.asList(impacts[i]), copyOf(actual.getImpacts(i)));
     }
   }
 
+  private static List<Impact> copyOf(FreqAndNormBuffer buffer) {
+    List<Impact> copy = new ArrayList<>();
+    for (int i = 0; i < buffer.size; ++i) {
+      copy.add(new Impact(buffer.freqs[i], buffer.norms[i]));
+    }
+    return copy;
+  }
+
   private static class DummyImpactsEnum extends ImpactsEnum {
 
     private int docID;
@@ -386,8 +396,10 @@ public class TestSynonymQuery extends LuceneTestCase {
         }
 
         @Override
-        public List<Impact> getImpacts(int level) {
-          return Arrays.asList(impacts[level]);
+        public FreqAndNormBuffer getImpacts(int level) {
+          FreqAndNormBuffer buffer = new FreqAndNormBuffer();
+          Arrays.stream(impacts[level]).forEach(impact -> buffer.add(impact.freq, impact.norm));
+          return buffer;
         }
       };
     }
@@ -507,7 +519,7 @@ public class TestSynonymQuery extends LuceneTestCase {
     // zero length SynonymQuery is rewritten
     SynonymQuery q = new SynonymQuery.Builder("f").build();
     assertTrue(q.getTerms().isEmpty());
-    assertEquals(searcher.rewrite(q), new MatchNoDocsQuery());
+    assertEquals(searcher.rewrite(q), MatchNoDocsQuery.INSTANCE);
 
     // non-boosted single term SynonymQuery is rewritten
     q = new SynonymQuery.Builder("f").addTerm(new Term("f"), 1f).build();
