@@ -137,7 +137,7 @@ public class TestTaskExecutor extends LuceneTestCase {
             };
 
         searcher.search(
-            new MatchAllDocsQuery(),
+            MatchAllDocsQuery.INSTANCE,
             new CollectorManager<Collector, Void>() {
               @Override
               public Collector newCollector() {
@@ -211,7 +211,7 @@ public class TestTaskExecutor extends LuceneTestCase {
             };
 
         searcher.search(
-            new MatchAllDocsQuery(),
+            MatchAllDocsQuery.INSTANCE,
             new CollectorManager<Collector, Void>() {
               @Override
               public Collector newCollector() {
