@@ -77,11 +77,14 @@ import org.apache.lucene.index.VectorSimilarityFunction;
 import org.apache.lucene.search.CollectionStatistics;
 import org.apache.lucene.search.DocIdSetIterator;
 import org.apache.lucene.search.IndexSearcher;
+import org.apache.lucene.search.KnnByteVectorQuery;
+import org.apache.lucene.search.KnnFloatVectorQuery;
 import org.apache.lucene.search.MatchAllDocsQuery;
 import org.apache.lucene.search.PhraseQuery;
 import org.apache.lucene.search.Query;
 import org.apache.lucene.search.TermQuery;
 import org.apache.lucene.search.TermStatistics;
+import org.apache.lucene.search.TopDocs;
 import org.apache.lucene.search.VectorScorer;
 import org.apache.lucene.search.similarities.BM25Similarity;
 import org.apache.lucene.search.similarities.ClassicSimilarity;
@@ -111,7 +114,7 @@ public class TestMemoryIndex extends LuceneTestCase {
     MemoryIndex mi = new MemoryIndex();
     mi.addField("f1", "some text", analyzer);
 
-    assertNotEquals(0.0f, mi.search(new MatchAllDocsQuery()));
+    assertNotEquals(0.0f, mi.search(MatchAllDocsQuery.INSTANCE));
     assertNotEquals(0.0f, mi.search(new TermQuery(new Term("f1", "some"))));
 
     // check we can add a new field after searching
@@ -793,6 +796,11 @@ public class TestMemoryIndex extends LuceneTestCase {
             .get(0)
             .reader()
             .getByteVectorValues("knnByteVectorValue"));
+    TopDocs docs =
+        mi.createSearcher()
+            .search(new KnnFloatVectorQuery("knnFloatA", new float[] {1.0f, 1.0f}, 1), 10);
+    // we don't really do knn search right now for MemoryIndex
+    assertEquals(0, docs.totalHits.value());
   }
 
   public void testKnnByteVectorOnlyOneVectorAllowed() throws IOException {
@@ -840,6 +848,10 @@ public class TestMemoryIndex extends LuceneTestCase {
             .get(0)
             .reader()
             .getFloatVectorValues("knnFloatVectorValue"));
+    TopDocs docs =
+        mi.createSearcher().search(new KnnByteVectorQuery("knnByteA", new byte[] {1, 1}, 1), 10);
+    // we don't really do knn search right now for MemoryIndex
+    assertEquals(0, docs.totalHits.value());
   }
 
   private static void assertFloatVectorValue(MemoryIndex mi, String fieldName, float[] expected)
