@@ -27,6 +27,6 @@ public class MatchAllDocsQueryBuilder implements QueryBuilder {
 
   @Override
   public Query getQuery(Element e) throws ParserException {
-    return new MatchAllDocsQuery();
+    return MatchAllDocsQuery.INSTANCE;
   }
 }
