@@ -19,9 +19,7 @@ package org.apache.lucene.tests.index;
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.Iterator;
-import java.util.List;
 import java.util.Objects;
-import java.util.RandomAccess;
 import org.apache.lucene.index.BinaryDocValues;
 import org.apache.lucene.index.DocValues;
 import org.apache.lucene.index.DocValuesSkipIndexType;
@@ -30,7 +28,7 @@ import org.apache.lucene.index.DocValuesType;
 import org.apache.lucene.index.FieldInfo;
 import org.apache.lucene.index.Fields;
 import org.apache.lucene.index.FilterLeafReader;
-import org.apache.lucene.index.Impact;
+import org.apache.lucene.index.FreqAndNormBuffer;
 import org.apache.lucene.index.Impacts;
 import org.apache.lucene.index.ImpactsEnum;
 import org.apache.lucene.index.LeafReader;
@@ -59,6 +57,7 @@ import org.apache.lucene.util.Bits;
 import org.apache.lucene.util.BytesRef;
 import org.apache.lucene.util.FixedBitSet;
 import org.apache.lucene.util.IOBooleanSupplier;
+import org.apache.lucene.util.LiveDocs;
 import org.apache.lucene.util.VirtualMethod;
 import org.apache.lucene.util.automaton.CompiledAutomaton;
 
@@ -735,12 +734,11 @@ public class AssertingLeafReader extends FilterLeafReader {
     }
 
     @Override
-    public List<Impact> getImpacts(int level) {
+    public FreqAndNormBuffer getImpacts(int level) {
       assert validFor == Math.max(impactsEnum.docID(), impactsEnum.lastShallowTarget)
           : "Cannot reuse impacts after advancing the iterator";
-      List<Impact> impacts = in.getImpacts(level);
-      assert impacts.size() <= 1 || impacts instanceof RandomAccess
-          : "impact lists longer than 1 should implement RandomAccess but saw impacts = " + impacts;
+      FreqAndNormBuffer impacts = in.getImpacts(level);
+      assert impacts.size > 0;
       return impacts;
     }
   }
@@ -840,6 +838,23 @@ public class AssertingLeafReader extends FilterLeafReader {
       return in.longValue();
     }
 
+    @Override
+    public void longValues(int size, int[] docs, long[] values, long defaultValue)
+        throws IOException {
+      assertThread("Numeric doc values", creationThread);
+      assert size >= 0;
+      assert size == 0 || docs[0] >= docID();
+      assert size == 0 || docs[0] >= 0;
+      for (int i = 1; i < size; ++i) {
+        assert docs[i] > docs[i - 1];
+      }
+      assert size == 0 || docs[size - 1] < maxDoc;
+      int expectedDocIdOnReturn = size == 0 ? docID() : docs[size - 1];
+      super.longValues(size, docs, values, defaultValue);
+      lastDocID = in.docID();
+      assert lastDocID == expectedDocIdOnReturn;
+    }
+
     @Override
     public String toString() {
       return "AssertingNumericDocValues(" + in + ")";
@@ -1838,7 +1853,11 @@ public class AssertingLeafReader extends FilterLeafReader {
     Bits liveDocs = super.getLiveDocs();
     if (liveDocs != null) {
       assert maxDoc() == liveDocs.length();
-      liveDocs = new AssertingBits(liveDocs);
+      if (liveDocs instanceof LiveDocs) {
+        liveDocs = new AssertingLiveDocs((LiveDocs) liveDocs);
+      } else {
+        liveDocs = new AssertingBits(liveDocs);
+      }
     } else {
       assert maxDoc() == numDocs();
       assert !hasDeletions();
@@ -1873,4 +1892,31 @@ public class AssertingLeafReader extends FilterLeafReader {
   public CacheHelper getReaderCacheHelper() {
     return in.getReaderCacheHelper();
   }
+
+  static class AssertingLiveDocs extends AssertingBits implements LiveDocs {
+    private final LiveDocs liveDocs;
+
+    AssertingLiveDocs(LiveDocs liveDocs) {
+      super(liveDocs);
+      this.liveDocs = liveDocs;
+    }
+
+    @Override
+    public int deletedCount() {
+      int count = liveDocs.deletedCount();
+      assert count >= 0;
+      assert count <= length();
+      return count;
+    }
+
+    @Override
+    public DocIdSetIterator liveDocsIterator() {
+      return liveDocs.liveDocsIterator();
+    }
+
+    @Override
+    public DocIdSetIterator deletedDocsIterator() {
+      return liveDocs.deletedDocsIterator();
+    }
+  }
 }
