@@ -75,7 +75,6 @@ import org.apache.lucene.tests.util.TestUtil;
 import org.apache.lucene.util.AttributeImpl;
 import org.apache.lucene.util.AttributeReflector;
 import org.apache.lucene.util.BytesRef;
-import org.apache.lucene.util.CollectionUtil;
 import org.apache.lucene.util.IOUtils;
 
 /**
@@ -251,8 +250,8 @@ public abstract class BaseTermVectorsFormatTestCase extends BaseIndexFileFormatT
         }
       }
 
-      positionToTerms = CollectionUtil.newHashMap(len);
-      startOffsetToTerms = CollectionUtil.newHashMap(len);
+      positionToTerms = HashMap.newHashMap(len);
+      startOffsetToTerms = HashMap.newHashMap(len);
       for (int i = 0; i < len; ++i) {
         positionToTerms.computeIfAbsent(positions[i], k -> new HashSet<>(1)).add(i);
         startOffsetToTerms.computeIfAbsent(startOffsets[i], k -> new HashSet<>(1)).add(i);
