@@ -16,6 +16,8 @@
  */
 package org.apache.lucene.tests.search;
 
+import static org.apache.lucene.tests.util.LuceneTestCase.rarely;
+
 import java.io.IOException;
 import org.apache.lucene.search.CheckedIntConsumer;
 import org.apache.lucene.search.DocIdSetIterator;
@@ -35,6 +37,8 @@ class AssertingLeafCollector extends FilterLeafCollector {
   private int lastCollected = -1;
   private boolean finishCalled;
 
+  private int[] docBuffer;
+
   AssertingLeafCollector(LeafCollector collector, int min, int max) {
     super(collector);
     this.min = min;
@@ -48,7 +52,20 @@ class AssertingLeafCollector extends FilterLeafCollector {
 
   @Override
   public void collect(DocIdStream stream) throws IOException {
-    in.collect(new AssertingDocIdStream(stream));
+    if (rarely()) {
+      if (docBuffer == null) {
+        docBuffer = new int[32];
+      }
+      for (int count = stream.intoArray(docBuffer);
+          count != 0;
+          count = stream.intoArray(docBuffer)) {
+        for (int i = 0; i < count; ++i) {
+          collect(docBuffer[i]);
+        }
+      }
+    } else {
+      in.collect(new AssertingDocIdStream(stream));
+    }
   }
 
   @Override
@@ -105,7 +122,8 @@ class AssertingLeafCollector extends FilterLeafCollector {
         assert docID() != -1;
         assert docID() != NO_MORE_DOCS;
         int nextNonMatchingDocID = in.docIDRunEnd();
-        assert nextNonMatchingDocID > docID();
+        assert nextNonMatchingDocID > docID()
+            : "docIDRunEnd=" + nextNonMatchingDocID + ", docID=" + docID();
         return nextNonMatchingDocID;
       }
     };
@@ -179,6 +197,45 @@ class AssertingLeafCollector extends FilterLeafCollector {
       return count;
     }
 
+    @Override
+    public int intoArray(int[] array) {
+      assert array.length > 0;
+      int count = stream.intoArray(array);
+      assert lastUpTo != DocIdSetIterator.NO_MORE_DOCS || count == 0;
+      if (count < array.length) {
+        lastUpTo = DocIdSetIterator.NO_MORE_DOCS;
+        assert stream.mayHaveRemaining() == false;
+      } else {
+        lastUpTo = array[array.length - 1] + 1;
+      }
+      return count;
+    }
+
+    @Override
+    public int intoArray(int upTo, int[] array) {
+      assert array.length > 0;
+      assert lastUpTo <= upTo : "upTo=" + upTo + " but previous upTo=" + lastUpTo;
+      int count = stream.intoArray(upTo, array);
+
+      assert lastUpTo != upTo || count == 0;
+
+      if (count != 0) {
+        assert array[count - 1] < upTo;
+      }
+
+      if (count < array.length) {
+        lastUpTo = upTo;
+      } else {
+        lastUpTo = array[array.length - 1] + 1;
+      }
+
+      if (upTo == DocIdSetIterator.NO_MORE_DOCS && count < array.length) {
+        assert stream.mayHaveRemaining() == false;
+      }
+
+      return count;
+    }
+
     @Override
     public boolean mayHaveRemaining() {
       boolean mayHaveRemaining = stream.mayHaveRemaining();
